==> new20-metadata-0.0.38-sources.jar: com/xforceplus/ultraman/app/new20/metadata/validator/UltramanEnumsConstraintValidator.java <==
package com.xforceplus.ultraman.app.new20.metadata.validator;

import com.xforceplus.ultraman.app.new20.metadata.validator.annotation.CheckUltramanEnums;

import com.xforceplus.ultraman.app.new20.metadata.dict.*;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * UltramanEnumsConstraintValidator
 * </p>
 *
 * @author ultraman
 * @since 2023-05-22
 */
public class UltramanEnumsConstraintValidator implements ConstraintValidator<CheckUltramanEnums, String> {

    private final String MSG_FORMAT = "value must be formed from codes of enum %s";

    Class clazz;

    @Override
    public void initialize(CheckUltramanEnums constraintAnnotation) {
        clazz = constraintAnnotation.value();
    }

    @Override
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if(null == value || value.length() == 0) {
            return true;
        }

        boolean isValid = true;
        List<String> vals = Arrays.asList(value.split(","));

        if(clazz.equals(FlowStatus.class)) {
            isValid = vals.stream()
                    .filter(val -> null != FlowStatus.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, FlowStatus.class.getSimpleName());
            }
        }
        if(clazz.equals(SnapshotFormat.class)) {
            isValid = vals.stream()
                    .filter(val -> null != SnapshotFormat.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, SnapshotFormat.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx001.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx001.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx001.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx002.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx002.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx002.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx003.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx003.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx003.class.getSimpleName());
            }
        }

        return isValid;
    }

    private void unValidMsg(ConstraintValidatorContext context, String enumName){
        context.disableDefaultConstraintViolation();
        context.buildConstraintViolationWithTemplate(
                        String.format(MSG_FORMAT, enumName))
                .addConstraintViolation();
    }
}

==> new20-metadata-0.0.72-sources.jar: com/xforceplus/ultraman/app/new20/metadata/validator/UltramanEnumsConstraintValidator.java <==
package com.xforceplus.ultraman.app.new20.metadata.validator;

import com.xforceplus.ultraman.app.new20.metadata.validator.annotation.CheckUltramanEnums;

import com.xforceplus.ultraman.app.new20.metadata.dict.*;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * UltramanEnumsConstraintValidator
 * </p>
 *
 * @author ultraman
 * @since 2023-06-12
 */
public class UltramanEnumsConstraintValidator implements ConstraintValidator<CheckUltramanEnums, String> {

    private final String MSG_FORMAT = "value must be formed from codes of enum %s";

    Class clazz;

    @Override
    public void initialize(CheckUltramanEnums constraintAnnotation) {
        clazz = constraintAnnotation.value();
    }

    @Override
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if(null == value || value.length() == 0) {
            return true;
        }

        boolean isValid = true;
        List<String> vals = Arrays.asList(value.split(","));

        if(clazz.equals(FlowStatus.class)) {
            isValid = vals.stream()
                    .filter(val -> null != FlowStatus.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, FlowStatus.class.getSimpleName());
            }
        }
        if(clazz.equals(SnapshotFormat.class)) {
            isValid = vals.stream()
                    .filter(val -> null != SnapshotFormat.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, SnapshotFormat.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx001.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx001.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx001.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx002.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx002.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx002.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx003.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx003.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx003.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx0526001.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx0526001.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx0526001.class.getSimpleName());
            }
        }
        if(clazz.equals(Mjx0605001.class)) {
            isValid = vals.stream()
                    .filter(val -> null != Mjx0605001.fromCode(val))
                    .count() == vals.size();
            if(!isValid) {
                unValidMsg(context, Mjx0605001.class.getSimpleName());
            }
        }

        return isValid;
    }

    private void unValidMsg(ConstraintValidatorContext context, String enumName){
        context.disableDefaultConstraintViolation();
        context.buildConstraintViolationWithTemplate(
                        String.format(MSG_FORMAT, enumName))
                .addConstraintViolation();
    }
}
